@@ -290,6 +290,7 @@ pub enum Endian {
 pub struct ULID(u128);
 
 unsafe impl Send for ULID {}
+unsafe impl Sync for ULID {}
 
 impl fmt::Display for ULID {
   fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
@@ -545,6 +546,9 @@ pub struct ULIDGenerator {
   rng: ThreadRng,
 }
 
+unsafe impl Send for ULIDGenerator {}
+unsafe impl Sync for ULIDGenerator {}
+
 impl ULIDGenerator {
   /// The Constructor for [ULIDGenerator].
   #[must_use]
